@@ -8,7 +8,7 @@ expand or other infrastructure or product changes occur.
 CONTROL_PANEL_URL = "https://timeweb.cloud/my"
 
 # Location specific parameters. May change later.
-REGIONS_WITH_IPV6 = ["ru-1", "ru-3", "pl-1", "nl-1"]
+REGIONS_WITH_IPV6 = ["ru-1", "ru-3", "pl-1", "nl-1", "kz-1"]
 REGIONS_WITH_IMAGES = ["ru-1", "ru-3", "kz-1", "pl-1", "nl-1"]
 REGIONS_WITH_LAN = ["ru-1", "ru-3", "nl-1", "pl-1", "de-1"]
 ZONES_WITH_LAN = [
